<?php

// If WooCommerce is active, do all the things
if ( is_woocommerce_activated() )

// Load WooCommerce stylsheet
if ( ! is_admin() ) { add_action( 'get_header', 'woo_load_woocommerce_css', 20 ); }

if ( ! function_exists( 'woo_load_woocommerce_css' ) ) {
	function woo_load_woocommerce_css () {
		wp_register_style( 'woocommerce', get_template_directory_uri() . '/css/woocommerce.css' );
		wp_enqueue_style( 'woocommerce' );
	}
}

/*-----------------------------------------------------------------------------------*/
/* This theme supports WooCommerce, woo! */
/*-----------------------------------------------------------------------------------*/

add_action( 'after_setup_theme', 'woocommerce_support' );
function woocommerce_support() {
	add_theme_support( 'woocommerce' );
}

/*-----------------------------------------------------------------------------------*/
/* Hook in on activation */
/*-----------------------------------------------------------------------------------*/

global $pagenow;
if ( is_admin() && isset( $_GET['activated'] ) && $pagenow == 'themes.php' ) add_action('init', 'woo_install_theme', 1);

/*-----------------------------------------------------------------------------------*/
/* Install */
/*-----------------------------------------------------------------------------------*/

if ( ! function_exists( 'woo_install_theme' ) ) {
	function woo_install_theme() {

	update_option( 'woocommerce_thumbnail_image_width', '200' );
	update_option( 'woocommerce_thumbnail_image_height', '200' );
	update_option( 'woocommerce_single_image_width', '500' ); // Single
	update_option( 'woocommerce_single_image_height', '500' ); // Single
	update_option( 'woocommerce_catalog_image_width', '400' ); // Catalog
	update_option( 'woocommerce_catalog_image_height', '400' ); // Catlog

	}
}

if ( ! function_exists( 'woocommerce_html5' ) ) {
	// Insert HTML5 Shiv
	add_action('wp_head', 'woocommerce_html5');

	function woocommerce_html5() {
		echo '<!--[if lt IE 9]><script src="https://html5shiv.googlecode.com/svn/trunk/html5.js"></script><![endif]-->';
	}
}

// Disable WooCommerce styles
add_action( 'wp', 'woo_wc_disable_css' );
if ( ! function_exists( 'woo_wc_disable_css' ) ) {
	function woo_wc_disable_css() {
		/**
		 * Disable WooCommerce styles
		 */
		if ( version_compare( WOOCOMMERCE_VERSION, "2.1" ) >= 0 ) {
			// WooCommerce 2.1 or above is active
			add_filter( 'woocommerce_enqueue_styles', '__return_false' );
		} else {
			// WooCommerce is less than 2.1
			define( 'WOOCOMMERCE_USE_CSS', false );
		}
	}
}

function woo_wc_dequeue_styles() {
	wp_dequeue_style( 'woocommerce_frontend_styles_layout' );
	wp_dequeue_style( 'woocommerce_frontend_styles_smallscreen' );
	wp_dequeue_style( 'woocommerce_frontend_styles' );
}

// Remove WC sidebar
remove_action( 'woocommerce_sidebar', 'woocommerce_get_sidebar', 10);

// WooCommerce overrides
remove_action( 'woocommerce_before_main_content', 'woocommerce_output_content_wrapper', 10);
remove_action( 'woocommerce_after_main_content', 'woocommerce_output_content_wrapper_end', 10);

if ( ! function_exists( 'woocommerce_biznizz_before_content' ) ) {
	// WooCommerce overrides
	add_action('woocommerce_before_main_content', 'woocommerce_biznizz_before_content', 20);
	function woocommerce_biznizz_before_content() {
		?>
		<!-- #content Starts -->

		<?php woo_content_before(); ?>
	    <div id="content">

	    	<div class="col-full">

		    	<div id="main-sidebar-container">

		            <!-- #main Starts -->
		            <?php woo_main_before(); ?>
		            <div id="main" class="col-left">
	    <?php
	}
}

if ( ! function_exists( 'woocommerce_biznizz_after_content' ) ) {
	// WooCommerce overrides
	add_action('woocommerce_after_main_content', 'woocommerce_biznizz_after_content', 30);
	function woocommerce_biznizz_after_content() {
		?>
					</div><!-- /#main -->
		            <?php woo_main_after(); ?>

				</div><!-- /#main-sidebar-container -->

			</div><!--/.col-full-->

	    </div><!-- /#content -->
		<?php woo_content_after(); ?>
	    <?php
	}
}

// Add the WC sidebar in the right place
add_action( 'woo_main_after', 'woocommerce_get_sidebar', 10);

// Remove breadcrumb
remove_action( 'woocommerce_before_main_content', 'woocommerce_breadcrumb', 20, 0);
add_action( 'woo_main_before', 'woocommerce_breadcrumb', 20, 0);


// Remove pagination (we're using the WooFramework default pagination)
// < 2.0
remove_action( 'woocommerce_pagination', 'woocommerce_pagination', 10 );
add_action( 'woocommerce_pagination', 'biznizz_commerce_pagination', 10 );
// 2.0 +
remove_action( 'woocommerce_after_shop_loop', 'woocommerce_pagination', 10 );
add_action( 'woocommerce_after_shop_loop', 'biznizz_commerce_pagination', 10 );

if ( ! function_exists( 'biznizz_commerce_pagination' ) ) {
	function biznizz_commerce_pagination() {
		if ( is_search() && is_post_type_archive() ) {
			add_filter( 'woo_pagination_args', 'woocommerceframework_add_search_fragment', 10 );
		}
		woo_pagenav();
	}
}

if ( ! function_exists( 'woocommerceframework_add_search_fragment' ) ) {
	function woocommerceframework_add_search_fragment ( $settings ) {
		$settings['add_fragment'] = '&post_type=product';
		return $settings;
	} // End woocommerceframework_add_search_fragment()
}


if ( ! function_exists( 'woocommerce_output_related_products' ) && version_compare( WOOCOMMERCE_VERSION, "2.1" ) < 0 ) {
	// Change columns in related products output to 3
	remove_action( 'woocommerce_after_single_product_summary', 'woocommerce_output_related_products', 20);
	add_action( 'woocommerce_after_single_product_summary', 'woocommerce_output_related_products', 20);
	function woocommerce_output_related_products() {
		woocommerce_related_products(3,3); // 3 products, 3 columns
	}
}

add_filter( 'woocommerce_output_related_products_args', 'biznizz_related_products' );
function biznizz_related_products() {
	$args = array(
		'posts_per_page' => 3,
		'columns'        => 3,
	);
	return $args;
}

// Change columns in upsells output to 3 and move below the product summary
remove_action( 'woocommerce_after_single_product_summary', 'woocommerce_upsell_display', 15 );
add_action( 'woocommerce_after_single_product_summary', 'woocommerceframework_upsell_display', 10);

if (!function_exists('woocommerceframework_upsell_display')) {
	function woocommerceframework_upsell_display() {
	    woocommerce_upsell_display(-1,3); // 3 products, 3 columns
	}
}

if ( ! function_exists( 'loop_columns' ) ) {
	// Change columns in product loop to 3
	function loop_columns() {
		if ( is_home() ) {
			return 4;
		} else {
			return 3;
		}
	}

	add_filter('loop_shop_columns', 'loop_columns');
}

// Display 12 products per page
add_filter('loop_shop_per_page', create_function('$cols', 'return 12;'));

// Fix sidebar on shop page
remove_action( 'woocommerce_sidebar', 'woocommerce_get_sidebar', 10);

if ( ! function_exists( 'woostore_star_sidebar' ) ) {
	// Adjust the star rating in the sidebar
	add_filter('woocommerce_star_rating_size_sidebar', 'woostore_star_sidebar');

	function woostore_star_sidebar() {
		return 12;
	}
}

if ( ! function_exists( 'woostore_star_reviews' ) ) {
	// Adjust the star rating in the recent reviews
	add_filter('woocommerce_star_rating_size_recent_reviews', 'woostore_star_reviews');

	function woostore_star_reviews() {
		return 12;
	}
}

if ( ! function_exists( 'biznizz_featured_products' ) ) {
	function biznizz_featured_products() {
		global $woo_options;
		if ( is_woocommerce_activated() && $woo_options[ 'woo_homepage_featured_products' ] == "true" ) {
	        echo '<h2>'.__('Featured Products', 'woothemes').'</h2>';
			echo do_shortcode('[featured_products per_page="4" columns=4]');
	    }
	}
}